# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2022 data-futures.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""InvenioRDM previewers."""
